require 'spec_helper'

describe CucumberOutputParser do

  describe ".parse_failed_features" do
    subject { CucumberOutputParser }

    let(:cucumber_output) {
      <<-OUTPUT
        blah blah blah

        cucumber features/thing.feature # here's a comment
        cucumber features/other_thing.feature # oh no, another comment
        cucumber -p parallel features/yet_other_thing.feature # oh no, another comment

        user 1.3.4,
        sys 328
      OUTPUT
    }

    it "removes non-cucumber-command lines" do
      output = described_class.parse_failed_features(cucumber_output)
      output.should == ["features/thing.feature", "features/other_thing.feature", "features/yet_other_thing.feature"]
    end

    it "removes cucumber commands at the beginning of the line" do
      output = described_class.parse_failed_features(cucumber_output)
      output.should == ["features/thing.feature", "features/other_thing.feature", "features/yet_other_thing.feature"]
    end

    it "removes cucumber comments at the end on the line" do
      output = described_class.parse_failed_features(cucumber_output)
      output.should == ["features/thing.feature", "features/other_thing.feature", "features/yet_other_thing.feature"]
    end

    it "collapses newlines" do
      output = described_class.parse_failed_features(cucumber_output)
      output.should == ["features/thing.feature", "features/other_thing.feature", "features/yet_other_thing.feature"]
    end
  end

end
